//
// MessagePack for C++ static resolution routine
//
// Copyright (C) 2015-2016 KONDO Takatoshi
//
//    Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE_1_0.txt or copy at
//    http://www.boost.org/LICENSE_1_0.txt)
//

#ifndef MSGPACK_META_HPP
#define MSGPACK_META_HPP

#include "msgpack/meta_decl.hpp"

#include "msgpack/v1/meta.hpp"

#endif // MSGPACK_META_HPP
